<?php

function imageeffects_pixelate_form($action) {
  $form['pixel'] = array(
    '#type' => 'textfield',
    '#title' => t('Block size in pixels'),
    '#required' => true,
	'#size' => 10,
    '#default_value' => isset($action['pixel']) ? $action['pixel'] : '1',
    '#description' => t('Enter a block size in pixels.'),
	'#element_validate' => array('imageeffects_pixelate_validate'),
  );
  return $form;
}

/**
 * Element validate handler to ensure that either a height or a width is
 * specified.
 */
function imageeffects_pixelate_validate($element, &$form_state) {
  if ($element['#value'] < 1) {
    form_error($element, t('Block size can not be less than 1 pixel.'));
  }
}

function imageeffects_pixelate_image(&$image, $data) {
  if (!imagefilter($image->resource, IMG_FILTER_PIXELATE, $data['pixel'], true)) {
    watchdog('imageeffects', 'pixelate image failed. image: %image, data: %data.', array('%path' => $image, '%data' => print_r($data, TRUE)), WATCHDOG_ERROR);
    return FALSE;
  }
  return TRUE;
}

function theme_imageeffects_pixelate($element) {
  return check_plain($element['#value']['pixel']);
}

function imageeffects_flip_form($action) {
  $form['flip'] = array(
    '#title' => t('Flip type'),
    '#type' => 'select',
    '#options' => array('0' => ' - Select - ', 'Horizontal' => 'Horizontal', 'Vertical' => 'Vertical', 'Both' => 'Both'),
    '#default_value' => isset($action['flip']) ? $action['flip'] : '1',
    '#description' => t('Select Flip (mirror) type.'),
	'#element_validate' => array('imageeffects_flip_validate'),
  );
  return $form;
}

function imageeffects_flip_validate($element, &$form_state) {
  if ('0' == $element['#value']) {
    form_error($element, t('Flip type field is required.'));
  }
}

function imageeffects_flip_image(&$image, $data) {

  $width = $image->info['width'];
  $height = $image->info['height'];
  $src_x = 0;
  $src_y = 0;
  $src_width = $width;
  $src_height = $height;
  
  switch($data['flip']) {
    case 'Horizontal':
     $src_x = $width -1;
       $src_width = -$width;
    break;
  
  case 'Vertical':
      $src_y = $height -1;
      $src_height = -$height;
    break;
  
  case 'Both':
      $src_x = $width -1;
      $src_y = $height -1;
      $src_width = -$width;
      $src_height = -$height;
    break;
  }
  
  $imgdest = imagecreatetruecolor ($width, $height);

  imagecolortransparent($imgdest, imagecolorallocate($image->resource, 0, 0, 0));
  imagealphablending($imgdest, false);
  imagesavealpha($imgdest, true);

  if(imagecopyresampled($imgdest, $image->resource, 0, 0, $src_x, $src_y , $width, $height, $src_width, $src_height)){
    $image->resource = $imgdest;
  } else {
	watchdog('imageeffects', 'imageeffects flip failed. image: %image.', array('%image' => $image->source), WATCHDOG_ERROR);
    return FALSE;
  }
  return TRUE;
}

function theme_imageeffects_flip($element) {
  return check_plain($element['#value']['flip']);
}